@@ -16,7 +16,7 @@
  * http://cvs.graphicsmagick.org/cgi-bin/cvsweb.cgi/GraphicsMagick/coders/jp2.c  
  * https://subversion.imagemagick.org/subversion/ImageMagick/trunk/coders/jp2.c
  * http://svn.ghostscript.com:8080/jasper/trunk/src/appl/jasper.c
- * http://websvn.kde.org/trunk/KDE/kdelibs/kimgio/jp2.cpp
+ * http://websvn.kde.org/trunk/KDE/tdelibs/kimgio/jp2.cpp
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -36,6 +36,16 @@
 // files io. Uncomment this line only for debugging.
 //#define ENABLE_DEBUG_MESSAGES
 
+// C ANSI includes.
+
+extern "C"
+{
+#if !defined(__STDC_LIMIT_MACROS)
+#define __STDC_LIMIT_MACROS
+#endif
+#include <stdint.h>
+}
+
 // TQt includes.
 
 #include <tqfile.h>
