@@ -49,13 +49,13 @@ extern "C"
 // KDE includes.
 
 #include <kmdcodec.h>
-#include <kfileitem.h>
-#include <kapplication.h>
+#include <tdefileitem.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kmimetype.h>
-#include <kfileitem.h>
-#include <kglobal.h>
+#include <tdefileitem.h>
+#include <tdeglobal.h>
 
 // LibKDcraw includes.
 
@@ -801,8 +801,8 @@ void ThumbBarView::slotFailedThumbnail(const KURL& url)
     if (!item)
         return;
 
-    KIconLoader* iconLoader = KApplication::kApplication()->iconLoader();
-    TQPixmap pix = iconLoader->loadIcon("image", KIcon::NoGroup, ThumbnailSize::Huge);
+    TDEIconLoader* iconLoader = TDEApplication::kApplication()->iconLoader();
+    TQPixmap pix = iconLoader->loadIcon("image-x-generic", TDEIcon::NoGroup, ThumbnailSize::Huge);
 
     if (item->d->pixmap)
     {
@@ -952,15 +952,15 @@ TQString ThumbBarToolTip::tipContent(ThumbBarItem* item)
         if (settings.showFileDate)
         {
             TQDateTime modifiedDate = fileInfo.lastModified();
-            str = KGlobal::locale()->formatDateTime(modifiedDate, true, true);
+            str = TDEGlobal::locale()->formatDateTime(modifiedDate, true, true);
             tipText += m_cellBeg + i18n("Modified:") + m_cellMid + str + m_cellEnd;
         }
 
         if (settings.showFileSize)
         {
             tipText += m_cellBeg + i18n("Size:") + m_cellMid;
-            str = i18n("%1 (%2)").arg(KIO::convertSize(fi.size()))
-                                .arg(KGlobal::locale()->formatNumber(fi.size(), 0));
+            str = i18n("%1 (%2)").arg(TDEIO::convertSize(fi.size()))
+                                .arg(TDEGlobal::locale()->formatNumber(fi.size(), 0));
             tipText += str + m_cellEnd;
         }
 
@@ -1037,7 +1037,7 @@ TQString ThumbBarToolTip::tipContent(ThumbBarItem* item)
             {
                 if (photoInfo.dateTime.isValid())
                 {
-                    str = KGlobal::locale()->formatDateTime(photoInfo.dateTime, true, true);
+                    str = TDEGlobal::locale()->formatDateTime(photoInfo.dateTime, true, true);
                     if (str.length() > m_maxStringLen) str = str.left(m_maxStringLen-3) + "...";
                     metaStr += m_cellBeg + i18n("Created:") + m_cellMid + TQStyleSheet::escape( str ) + m_cellEnd;
                 }
